@@ -30,7 +30,8 @@ from itertools import *
 from functools import partial
 from calculate.lib.datavars import VariableError
 
-from calculate.lib.utils.files import (isMount, removeDir,
+from calculate.lib.utils.mount import isMount
+from calculate.lib.utils.files import (removeDir,
                                        processProgress, STDOUT,
                                        typeFile, pathJoin, process,
                                        listDirectory, checkUtils,
@@ -38,8 +39,9 @@ from calculate.lib.utils.files import (isMount, removeDir,
                                        MAGIC_CONTINUE, makeDirectory,
                                        isEmpty, check_rw, calculate_exclude,
                                        PercentProgress, getProgPath, xztaropen)
+import calculate.lib.utils.device as device
 from calculate.lib.utils.device import (detectDeviceForPartition,
-                                        getUdevDeviceInfo, countPartitions)
+                                        countPartitions)
 from calculate.lib.utils.tools import classproperty, Signal, traverse
 from calculate.lib.utils.text import _u8
 from calculate.lib.variables.linux import LinuxDataVars, Linux
@@ -299,7 +301,10 @@ class Distributive(object):
 
     def getEfiDirectory(self):
         """Get directory which contains boot/efi"""
-        return path.join(self.getDirectory(), "boot/efi")
+        return self.getEfiDirectories()[0]
+
+    def getEfiDirectories(self):
+        return [path.join(self.getDirectory(), "boot/efi")]
 
     def _makeDirectory(self, pathname):
         """Make directory and parent.
@@ -444,6 +449,7 @@ class Distributive(object):
 
     def _mountToDirectory(self, file, directory, mountopts="", count=2):
         """Mount squashfs to directory"""
+        # 2816 code return by mount if device is absent (update /dev by udev)
         NO_SUCH_DEVICE = 2816
         if isMount(directory):
             raise DistributiveError(
@@ -456,7 +462,6 @@ class Distributive(object):
         if mountProcess.success():
             return True
         else:
-            # 2816 code return by mount if device is absent (update /dev by udev)
             # try mount 3 times with interval 0.5 second
             if mountProcess.returncode() == NO_SUCH_DEVICE and count:
                 sleep(0.5)
@@ -1048,6 +1053,12 @@ class PartitionDistributive(Distributive):
                                                 parent=dirObj)
                 DirectoryDistributive(realDestDir, parent=partObj)
 
+    def getEfiDirectories(self):
+        return [path.join(self.getDirectory(), x)
+            for x in self.multipartition.getMountPoints()
+            if x.startswith("/boot/efi")
+        ]
+
     def getMultipartData(self):
         """Get multipartition data"""
         mulipartData = zip(self.multipartition.getPartitions(),
@@ -1179,9 +1190,9 @@ class PartitionDistributive(Distributive):
         elif deviceName == "":
             return True
         fdiskProg, gdiskProg = checkUtils('/sbin/fdisk', '/usr/sbin/gdisk')
-        partitionNumber = \
-            getUdevDeviceInfo(name=dev).get('ID_PART_ENTRY_NUMBER', '') or \
-            getUdevDeviceInfo(name=dev).get('UDISKS_PARTITION_NUMBER', '')
+        info = device.udev.get_device_info(name=dev)
+        partitionNumber = (info.get('ID_PART_ENTRY_NUMBER','') or 
+            info.get('UDISKS_PARTITION_NUMBER', ''))
         devicePartitionCount = countPartitions(deviceName)
         if deviceName and not partitionNumber:
             raise DistributiveError(
