@@ -148,8 +148,7 @@ class VariableClMigrateRootPwdPlain(GrubHelper, UserHelper, Variable):
         if (value == self.stub_hash_value and
                 not self.read_hash_from_passwd() and
                 self.GetBool('cl_grub_passwd_set')):
-            raise PasswordError(_("Please specify root password "
-                                  "for the grub menu"))
+            raise PasswordError(_("Please specify a root password for Grub"))
 
 
 class VariableClMigrateRootPwd(ReadonlyVariable):
@@ -198,8 +197,8 @@ class VariableClGrubPasswdSet(GrubHelper, Variable):
     opt = ["--grub-passwd"]
 
     def init(self):
-        self.help = _("use root password for editing boot menu")
-        self.label = _("Use root password for editing boot menu")
+        self.help = _("use the root password to edit Grub")
+        self.label = _("Use the root password to edit Grub")
 
     def get(self):
         if (self.read_hash_from_passwd() or
@@ -253,7 +252,8 @@ class VariableClGrubPwd(GrubHelper, Variable):
     def check(self, value):
         if value and self.GetBool('cl_grub_remove_pwd_set'):
             raise VariableError(
-                _("Setting the password is uncompatible with removing the password"))
+                _("You cannot set a password and remove the "
+                  "existing password at a time"))
 
 
 class VariableClGrubRemovePwdSet(Variable):
@@ -267,8 +267,8 @@ class VariableClGrubRemovePwdSet(Variable):
     opt = ["--remove-passwd"]
 
     def init(self):
-        self.help = _("remove the password for editing the grub menu")
-        self.label = _("Remove the grub menu password")
+        self.help = _("remove the password protection for editing the Grub menu")
+        self.label = _("Remove the password protection on Grub")
 
 
 class VariableClInstallHomeCryptSet(UserHelper, Variable):
@@ -348,7 +348,9 @@ class VariableClMigrateUser(UserHelper, Variable):
         """
         Migrating users (users above 1000 uid)
         """
-        return filter("root".__ne__, getPasswdUsers())
+        cached_users = getPasswdUsers(
+            datafile="var/lib/calculate/calculate-client/cache/create_passwd")
+        return [x for x in getPasswdUsers() if x != "root" and x not in cached_users]
 
     def check(self, value):
         """
